# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.referral import Referral  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestReferral(unittest.TestCase):
    """Referral unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Referral
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.referral.Referral()  # noqa: E501
        if include_optional :
            return Referral(
                id = 56, 
                referrer_id = 56, 
                name = '0', 
                usage_limit = 56, 
                usage_count = 56, 
                created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                link = 'https://t.me/zarbanwalletbot?start=referral-29', 
                share_url = 'https://t.me/zarbanwalletbot?start=referral-29'
            )
        else :
            return Referral(
                id = 56,
                referrer_id = 56,
                usage_limit = 56,
                usage_count = 56,
                created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
        )

    def testReferral(self):
        """Test Referral"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.order_response import OrderResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestOrderResponse(unittest.TestCase):
    """OrderResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrderResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.order_response.OrderResponse()  # noqa: E501
        if include_optional :
            return OrderResponse(
                data = [
                    zarban.service.openapi_client.models.order.Order(
                        quote_id = 'a', 
                        outputs = [
                            zarban.service.openapi_client.models.raw_dutch_amount.RawDutchAmount(
                                token = 'a', 
                                start_amount = '0', 
                                end_amount = '0', 
                                recipient = 'a', )
                            ], 
                        encoded_order = 'a', 
                        signature = 'a', 
                        input = zarban.service.openapi_client.models.raw_dutch_amount.RawDutchAmount(
                            token = 'a', 
                            start_amount = '0', 
                            end_amount = '0', 
                            recipient = 'a', ), 
                        order_status = 'open', 
                        chain_id = 56, 
                        order_hash = 'a', 
                        order_type = 'dutch', )
                    ]
            )
        else :
            return OrderResponse(
                data = [
                    zarban.service.openapi_client.models.order.Order(
                        quote_id = 'a', 
                        outputs = [
                            zarban.service.openapi_client.models.raw_dutch_amount.RawDutchAmount(
                                token = 'a', 
                                start_amount = '0', 
                                end_amount = '0', 
                                recipient = 'a', )
                            ], 
                        encoded_order = 'a', 
                        signature = 'a', 
                        input = zarban.service.openapi_client.models.raw_dutch_amount.RawDutchAmount(
                            token = 'a', 
                            start_amount = '0', 
                            end_amount = '0', 
                            recipient = 'a', ), 
                        order_status = 'open', 
                        chain_id = 56, 
                        order_hash = 'a', 
                        order_type = 'dutch', )
                    ],
        )

    def testOrderResponse(self):
        """Test OrderResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.redemption_response import RedemptionResponse  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestRedemptionResponse(unittest.TestCase):
    """RedemptionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RedemptionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.redemption_response.RedemptionResponse()  # noqa: E501
        if include_optional :
            return RedemptionResponse(
                data = [
                    zarban.wallet.openapi_client.models.redemption.Redemption(
                        amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        destination_bank_info = zarban.wallet.openapi_client.models.bank_info.BankInfo(
                            bank_name = 'Bank Melli', 
                            card_number = '1234567890', 
                            iban = 'IR1234567890', ), 
                        status = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        id = '1234567890', 
                        created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        updated_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        paya_tracking_code = '1234567890', )
                    ]
            )
        else :
            return RedemptionResponse(
                data = [
                    zarban.wallet.openapi_client.models.redemption.Redemption(
                        amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        destination_bank_info = zarban.wallet.openapi_client.models.bank_info.BankInfo(
                            bank_name = 'Bank Melli', 
                            card_number = '1234567890', 
                            iban = 'IR1234567890', ), 
                        status = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        id = '1234567890', 
                        created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        updated_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        paya_tracking_code = '1234567890', )
                    ],
        )

    def testRedemptionResponse(self):
        """Test RedemptionResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class OrderInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'chain_id': 'int',
        'permit2_address': 'str',
        'reactor': 'str',
        'swapper': 'str',
        'nonce': 'str',
        'deadline': 'Timestamp',
        'additional_validation_contract': 'str',
        'additional_validation_data': 'str',
        'decay_start_time': 'Timestamp',
        'decay_end_time': 'Timestamp',
        'exclusive_filler': 'str',
        'exclusivity_override_bps': 'int',
        'input': 'DutchAmount',
        'outputs': 'list[DutchAmount]'
    }

    attribute_map = {
        'chain_id': 'chainId',
        'permit2_address': 'permit2Address',
        'reactor': 'reactor',
        'swapper': 'swapper',
        'nonce': 'nonce',
        'deadline': 'deadline',
        'additional_validation_contract': 'additionalValidationContract',
        'additional_validation_data': 'additionalValidationData',
        'decay_start_time': 'decayStartTime',
        'decay_end_time': 'decayEndTime',
        'exclusive_filler': 'exclusiveFiller',
        'exclusivity_override_bps': 'exclusivityOverrideBps',
        'input': 'input',
        'outputs': 'outputs'
    }

    def __init__(self, chain_id=None, permit2_address=None, reactor=None, swapper=None, nonce=None, deadline=None, additional_validation_contract=None, additional_validation_data=None, decay_start_time=None, decay_end_time=None, exclusive_filler=None, exclusivity_override_bps=None, input=None, outputs=None, local_vars_configuration=None):  # noqa: E501
        """OrderInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._chain_id = None
        self._permit2_address = None
        self._reactor = None
        self._swapper = None
        self._nonce = None
        self._deadline = None
        self._additional_validation_contract = None
        self._additional_validation_data = None
        self._decay_start_time = None
        self._decay_end_time = None
        self._exclusive_filler = None
        self._exclusivity_override_bps = None
        self._input = None
        self._outputs = None
        self.discriminator = None

        self.chain_id = chain_id
        self.permit2_address = permit2_address
        self.reactor = reactor
        self.swapper = swapper
        self.nonce = nonce
        self.deadline = deadline
        self.additional_validation_contract = additional_validation_contract
        self.additional_validation_data = additional_validation_data
        self.decay_start_time = decay_start_time
        self.decay_end_time = decay_end_time
        self.exclusive_filler = exclusive_filler
        self.exclusivity_override_bps = exclusivity_override_bps
        self.input = input
        self.outputs = outputs

    @property
    def chain_id(self):
        """Gets the chain_id of this OrderInfo.  # noqa: E501


        :return: The chain_id of this OrderInfo.  # noqa: E501
        :rtype: int
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this OrderInfo.


        :param chain_id: The chain_id of this OrderInfo.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and chain_id is None:  # noqa: E501
            raise ValueError("Invalid value for `chain_id`, must not be `None`")  # noqa: E501

        self._chain_id = chain_id

    @property
    def permit2_address(self):
        """Gets the permit2_address of this OrderInfo.  # noqa: E501


        :return: The permit2_address of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._permit2_address

    @permit2_address.setter
    def permit2_address(self, permit2_address):
        """Sets the permit2_address of this OrderInfo.


        :param permit2_address: The permit2_address of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and permit2_address is None:  # noqa: E501
            raise ValueError("Invalid value for `permit2_address`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                permit2_address is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', permit2_address)):  # noqa: E501
            raise ValueError(r"Invalid value for `permit2_address`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._permit2_address = permit2_address

    @property
    def reactor(self):
        """Gets the reactor of this OrderInfo.  # noqa: E501


        :return: The reactor of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._reactor

    @reactor.setter
    def reactor(self, reactor):
        """Sets the reactor of this OrderInfo.


        :param reactor: The reactor of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reactor is None:  # noqa: E501
            raise ValueError("Invalid value for `reactor`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reactor is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', reactor)):  # noqa: E501
            raise ValueError(r"Invalid value for `reactor`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._reactor = reactor

    @property
    def swapper(self):
        """Gets the swapper of this OrderInfo.  # noqa: E501


        :return: The swapper of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._swapper

    @swapper.setter
    def swapper(self, swapper):
        """Sets the swapper of this OrderInfo.


        :param swapper: The swapper of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and swapper is None:  # noqa: E501
            raise ValueError("Invalid value for `swapper`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                swapper is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', swapper)):  # noqa: E501
            raise ValueError(r"Invalid value for `swapper`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._swapper = swapper

    @property
    def nonce(self):
        """Gets the nonce of this OrderInfo.  # noqa: E501


        :return: The nonce of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._nonce

    @nonce.setter
    def nonce(self, nonce):
        """Sets the nonce of this OrderInfo.


        :param nonce: The nonce of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and nonce is None:  # noqa: E501
            raise ValueError("Invalid value for `nonce`, must not be `None`")  # noqa: E501

        self._nonce = nonce

    @property
    def deadline(self):
        """Gets the deadline of this OrderInfo.  # noqa: E501


        :return: The deadline of this OrderInfo.  # noqa: E501
        :rtype: Timestamp
        """
        return self._deadline

    @deadline.setter
    def deadline(self, deadline):
        """Sets the deadline of this OrderInfo.


        :param deadline: The deadline of this OrderInfo.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and deadline is None:  # noqa: E501
            raise ValueError("Invalid value for `deadline`, must not be `None`")  # noqa: E501

        self._deadline = deadline

    @property
    def additional_validation_contract(self):
        """Gets the additional_validation_contract of this OrderInfo.  # noqa: E501


        :return: The additional_validation_contract of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._additional_validation_contract

    @additional_validation_contract.setter
    def additional_validation_contract(self, additional_validation_contract):
        """Sets the additional_validation_contract of this OrderInfo.


        :param additional_validation_contract: The additional_validation_contract of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and additional_validation_contract is None:  # noqa: E501
            raise ValueError("Invalid value for `additional_validation_contract`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                additional_validation_contract is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', additional_validation_contract)):  # noqa: E501
            raise ValueError(r"Invalid value for `additional_validation_contract`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._additional_validation_contract = additional_validation_contract

    @property
    def additional_validation_data(self):
        """Gets the additional_validation_data of this OrderInfo.  # noqa: E501


        :return: The additional_validation_data of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._additional_validation_data

    @additional_validation_data.setter
    def additional_validation_data(self, additional_validation_data):
        """Sets the additional_validation_data of this OrderInfo.


        :param additional_validation_data: The additional_validation_data of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and additional_validation_data is None:  # noqa: E501
            raise ValueError("Invalid value for `additional_validation_data`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                additional_validation_data is not None and not re.search(r'^(0x)?[0-9a-fA-F]*$', additional_validation_data)):  # noqa: E501
            raise ValueError(r"Invalid value for `additional_validation_data`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]*$/`")  # noqa: E501

        self._additional_validation_data = additional_validation_data

    @property
    def decay_start_time(self):
        """Gets the decay_start_time of this OrderInfo.  # noqa: E501


        :return: The decay_start_time of this OrderInfo.  # noqa: E501
        :rtype: Timestamp
        """
        return self._decay_start_time

    @decay_start_time.setter
    def decay_start_time(self, decay_start_time):
        """Sets the decay_start_time of this OrderInfo.


        :param decay_start_time: The decay_start_time of this OrderInfo.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and decay_start_time is None:  # noqa: E501
            raise ValueError("Invalid value for `decay_start_time`, must not be `None`")  # noqa: E501

        self._decay_start_time = decay_start_time

    @property
    def decay_end_time(self):
        """Gets the decay_end_time of this OrderInfo.  # noqa: E501


        :return: The decay_end_time of this OrderInfo.  # noqa: E501
        :rtype: Timestamp
        """
        return self._decay_end_time

    @decay_end_time.setter
    def decay_end_time(self, decay_end_time):
        """Sets the decay_end_time of this OrderInfo.


        :param decay_end_time: The decay_end_time of this OrderInfo.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and decay_end_time is None:  # noqa: E501
            raise ValueError("Invalid value for `decay_end_time`, must not be `None`")  # noqa: E501

        self._decay_end_time = decay_end_time

    @property
    def exclusive_filler(self):
        """Gets the exclusive_filler of this OrderInfo.  # noqa: E501


        :return: The exclusive_filler of this OrderInfo.  # noqa: E501
        :rtype: str
        """
        return self._exclusive_filler

    @exclusive_filler.setter
    def exclusive_filler(self, exclusive_filler):
        """Sets the exclusive_filler of this OrderInfo.


        :param exclusive_filler: The exclusive_filler of this OrderInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and exclusive_filler is None:  # noqa: E501
            raise ValueError("Invalid value for `exclusive_filler`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                exclusive_filler is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', exclusive_filler)):  # noqa: E501
            raise ValueError(r"Invalid value for `exclusive_filler`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._exclusive_filler = exclusive_filler

    @property
    def exclusivity_override_bps(self):
        """Gets the exclusivity_override_bps of this OrderInfo.  # noqa: E501


        :return: The exclusivity_override_bps of this OrderInfo.  # noqa: E501
        :rtype: int
        """
        return self._exclusivity_override_bps

    @exclusivity_override_bps.setter
    def exclusivity_override_bps(self, exclusivity_override_bps):
        """Sets the exclusivity_override_bps of this OrderInfo.


        :param exclusivity_override_bps: The exclusivity_override_bps of this OrderInfo.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and exclusivity_override_bps is None:  # noqa: E501
            raise ValueError("Invalid value for `exclusivity_override_bps`, must not be `None`")  # noqa: E501

        self._exclusivity_override_bps = exclusivity_override_bps

    @property
    def input(self):
        """Gets the input of this OrderInfo.  # noqa: E501


        :return: The input of this OrderInfo.  # noqa: E501
        :rtype: DutchAmount
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this OrderInfo.


        :param input: The input of this OrderInfo.  # noqa: E501
        :type: DutchAmount
        """
        if self.local_vars_configuration.client_side_validation and input is None:  # noqa: E501
            raise ValueError("Invalid value for `input`, must not be `None`")  # noqa: E501

        self._input = input

    @property
    def outputs(self):
        """Gets the outputs of this OrderInfo.  # noqa: E501


        :return: The outputs of this OrderInfo.  # noqa: E501
        :rtype: list[DutchAmount]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this OrderInfo.


        :param outputs: The outputs of this OrderInfo.  # noqa: E501
        :type: list[DutchAmount]
        """
        if self.local_vars_configuration.client_side_validation and outputs is None:  # noqa: E501
            raise ValueError("Invalid value for `outputs`, must not be `None`")  # noqa: E501

        self._outputs = outputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrderInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class ChainActivity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'step_number': 'int',
        'number_of_steps': 'int',
        'steps': 'list[ChainActivityStep]'
    }

    attribute_map = {
        'step_number': 'stepNumber',
        'number_of_steps': 'numberOfSteps',
        'steps': 'steps'
    }

    def __init__(self, step_number=None, number_of_steps=None, steps=None, local_vars_configuration=None):  # noqa: E501
        """ChainActivity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._step_number = None
        self._number_of_steps = None
        self._steps = None
        self.discriminator = None

        self.step_number = step_number
        self.number_of_steps = number_of_steps
        self.steps = steps

    @property
    def step_number(self):
        """Gets the step_number of this ChainActivity.  # noqa: E501


        :return: The step_number of this ChainActivity.  # noqa: E501
        :rtype: int
        """
        return self._step_number

    @step_number.setter
    def step_number(self, step_number):
        """Sets the step_number of this ChainActivity.


        :param step_number: The step_number of this ChainActivity.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and step_number is None:  # noqa: E501
            raise ValueError("Invalid value for `step_number`, must not be `None`")  # noqa: E501

        self._step_number = step_number

    @property
    def number_of_steps(self):
        """Gets the number_of_steps of this ChainActivity.  # noqa: E501


        :return: The number_of_steps of this ChainActivity.  # noqa: E501
        :rtype: int
        """
        return self._number_of_steps

    @number_of_steps.setter
    def number_of_steps(self, number_of_steps):
        """Sets the number_of_steps of this ChainActivity.


        :param number_of_steps: The number_of_steps of this ChainActivity.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and number_of_steps is None:  # noqa: E501
            raise ValueError("Invalid value for `number_of_steps`, must not be `None`")  # noqa: E501

        self._number_of_steps = number_of_steps

    @property
    def steps(self):
        """Gets the steps of this ChainActivity.  # noqa: E501


        :return: The steps of this ChainActivity.  # noqa: E501
        :rtype: list[ChainActivityStep]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this ChainActivity.


        :param steps: The steps of this ChainActivity.  # noqa: E501
        :type: list[ChainActivityStep]
        """
        if self.local_vars_configuration.client_side_validation and steps is None:  # noqa: E501
            raise ValueError("Invalid value for `steps`, must not be `None`")  # noqa: E501

        self._steps = steps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChainActivity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChainActivity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.eip712_sign_request import EIP712SignRequest  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestEIP712SignRequest(unittest.TestCase):
    """EIP712SignRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EIP712SignRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.eip712_sign_request.EIP712SignRequest()  # noqa: E501
        if include_optional :
            return EIP712SignRequest(
                name = 'Permit2', 
                typed_data = zarban.service.openapi_client.models.typed_data.TypedData(
                    types = {
                        'key' : [
                            zarban.service.openapi_client.models.type.Type(
                                name = '0', 
                                type = '0', )
                            ]
                        }, 
                    primary_type = '0', 
                    domain = zarban.service.openapi_client.models.typed_data_domain.TypedDataDomain(
                        name = '0', 
                        version = '0', 
                        chain_id = '0', 
                        verifying_contract = '0', 
                        salt = '0', ), 
                    message = { }, ), 
                hash = 'a'
            )
        else :
            return EIP712SignRequest(
                name = 'Permit2',
                typed_data = zarban.service.openapi_client.models.typed_data.TypedData(
                    types = {
                        'key' : [
                            zarban.service.openapi_client.models.type.Type(
                                name = '0', 
                                type = '0', )
                            ]
                        }, 
                    primary_type = '0', 
                    domain = zarban.service.openapi_client.models.typed_data_domain.TypedDataDomain(
                        name = '0', 
                        version = '0', 
                        chain_id = '0', 
                        verifying_contract = '0', 
                        salt = '0', ), 
                    message = { }, ),
                hash = 'a',
        )

    def testEIP712SignRequest(self):
        """Test EIP712SignRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class Log(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'contract': 'str',
        'timestamp': 'Timestamp',
        'address': 'str',
        'block_number': 'int',
        'tx_hash': 'str',
        'block_hash': 'str',
        'index': 'int',
        'topics': 'list[str]',
        'data': 'str',
        'decoded': 'dict(str, str)'
    }

    attribute_map = {
        'name': 'name',
        'contract': 'contract',
        'timestamp': 'timestamp',
        'address': 'address',
        'block_number': 'blockNumber',
        'tx_hash': 'txHash',
        'block_hash': 'blockHash',
        'index': 'index',
        'topics': 'topics',
        'data': 'data',
        'decoded': 'decoded'
    }

    def __init__(self, name=None, contract=None, timestamp=None, address=None, block_number=None, tx_hash=None, block_hash=None, index=None, topics=None, data=None, decoded=None, local_vars_configuration=None):  # noqa: E501
        """Log - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._contract = None
        self._timestamp = None
        self._address = None
        self._block_number = None
        self._tx_hash = None
        self._block_hash = None
        self._index = None
        self._topics = None
        self._data = None
        self._decoded = None
        self.discriminator = None

        self.name = name
        self.contract = contract
        self.timestamp = timestamp
        self.address = address
        self.block_number = block_number
        self.tx_hash = tx_hash
        self.block_hash = block_hash
        self.index = index
        self.topics = topics
        self.data = data
        if decoded is not None:
            self.decoded = decoded

    @property
    def name(self):
        """Gets the name of this Log.  # noqa: E501

        The name of the log  # noqa: E501

        :return: The name of this Log.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Log.

        The name of the log  # noqa: E501

        :param name: The name of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def contract(self):
        """Gets the contract of this Log.  # noqa: E501

        The contract address  # noqa: E501

        :return: The contract of this Log.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this Log.

        The contract address  # noqa: E501

        :param contract: The contract of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and contract is None:  # noqa: E501
            raise ValueError("Invalid value for `contract`, must not be `None`")  # noqa: E501

        self._contract = contract

    @property
    def timestamp(self):
        """Gets the timestamp of this Log.  # noqa: E501


        :return: The timestamp of this Log.  # noqa: E501
        :rtype: Timestamp
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Log.


        :param timestamp: The timestamp of this Log.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def address(self):
        """Gets the address of this Log.  # noqa: E501

        The Ethereum address  # noqa: E501

        :return: The address of this Log.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Log.

        The Ethereum address  # noqa: E501

        :param address: The address of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address is None:  # noqa: E501
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def block_number(self):
        """Gets the block_number of this Log.  # noqa: E501

        The block number  # noqa: E501

        :return: The block_number of this Log.  # noqa: E501
        :rtype: int
        """
        return self._block_number

    @block_number.setter
    def block_number(self, block_number):
        """Sets the block_number of this Log.

        The block number  # noqa: E501

        :param block_number: The block_number of this Log.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and block_number is None:  # noqa: E501
            raise ValueError("Invalid value for `block_number`, must not be `None`")  # noqa: E501

        self._block_number = block_number

    @property
    def tx_hash(self):
        """Gets the tx_hash of this Log.  # noqa: E501

        The transaction hash  # noqa: E501

        :return: The tx_hash of this Log.  # noqa: E501
        :rtype: str
        """
        return self._tx_hash

    @tx_hash.setter
    def tx_hash(self, tx_hash):
        """Sets the tx_hash of this Log.

        The transaction hash  # noqa: E501

        :param tx_hash: The tx_hash of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tx_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `tx_hash`, must not be `None`")  # noqa: E501

        self._tx_hash = tx_hash

    @property
    def block_hash(self):
        """Gets the block_hash of this Log.  # noqa: E501

        The block hash  # noqa: E501

        :return: The block_hash of this Log.  # noqa: E501
        :rtype: str
        """
        return self._block_hash

    @block_hash.setter
    def block_hash(self, block_hash):
        """Sets the block_hash of this Log.

        The block hash  # noqa: E501

        :param block_hash: The block_hash of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and block_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `block_hash`, must not be `None`")  # noqa: E501

        self._block_hash = block_hash

    @property
    def index(self):
        """Gets the index of this Log.  # noqa: E501

        The index  # noqa: E501

        :return: The index of this Log.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this Log.

        The index  # noqa: E501

        :param index: The index of this Log.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and index is None:  # noqa: E501
            raise ValueError("Invalid value for `index`, must not be `None`")  # noqa: E501

        self._index = index

    @property
    def topics(self):
        """Gets the topics of this Log.  # noqa: E501


        :return: The topics of this Log.  # noqa: E501
        :rtype: list[str]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        """Sets the topics of this Log.


        :param topics: The topics of this Log.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and topics is None:  # noqa: E501
            raise ValueError("Invalid value for `topics`, must not be `None`")  # noqa: E501

        self._topics = topics

    @property
    def data(self):
        """Gets the data of this Log.  # noqa: E501

        The data of the log  # noqa: E501

        :return: The data of this Log.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this Log.

        The data of the log  # noqa: E501

        :param data: The data of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and data is None:  # noqa: E501
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def decoded(self):
        """Gets the decoded of this Log.  # noqa: E501

        The decoded log, if available  # noqa: E501

        :return: The decoded of this Log.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._decoded

    @decoded.setter
    def decoded(self, decoded):
        """Sets the decoded of this Log.

        The decoded log, if available  # noqa: E501

        :param decoded: The decoded of this Log.  # noqa: E501
        :type: dict(str, str)
        """

        self._decoded = decoded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Log):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Log):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.vault_events_response import VaultEventsResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestVaultEventsResponse(unittest.TestCase):
    """VaultEventsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VaultEventsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.vault_events_response.VaultEventsResponse()  # noqa: E501
        if include_optional :
            return VaultEventsResponse(
                data = [
                    zarban.service.openapi_client.models.extended_event.ExtendedEvent(
                        domain = 'stableCoinSystem', 
                        id = 56, 
                        name = 'VaultRepay', 
                        raw = zarban.service.openapi_client.models.log.Log(
                            name = '0', 
                            contract = '0', 
                            timestamp = zarban.service.openapi_client.models.timestamp.Timestamp(
                                jalaali = '1399-01-01T00:00:00Z', 
                                gregorian = '2020-01-01T00:00:00Z', ), 
                            address = '0', 
                            block_number = 56, 
                            tx_hash = '0', 
                            block_hash = '0', 
                            index = 56, 
                            topics = [
                                '0x1234567890abcdef1234567abcdef'
                                ], 
                            data = '0x1234567890abcdef1234567abcdef', 
                            decoded = {
                                'key' : '0x1234567890abcdef1234567abcdef'
                                }, ), 
                        type = 'executive', 
                        payload = { }, )
                    ]
            )
        else :
            return VaultEventsResponse(
                data = [
                    zarban.service.openapi_client.models.extended_event.ExtendedEvent(
                        domain = 'stableCoinSystem', 
                        id = 56, 
                        name = 'VaultRepay', 
                        raw = zarban.service.openapi_client.models.log.Log(
                            name = '0', 
                            contract = '0', 
                            timestamp = zarban.service.openapi_client.models.timestamp.Timestamp(
                                jalaali = '1399-01-01T00:00:00Z', 
                                gregorian = '2020-01-01T00:00:00Z', ), 
                            address = '0', 
                            block_number = 56, 
                            tx_hash = '0', 
                            block_hash = '0', 
                            index = 56, 
                            topics = [
                                '0x1234567890abcdef1234567abcdef'
                                ], 
                            data = '0x1234567890abcdef1234567abcdef', 
                            decoded = {
                                'key' : '0x1234567890abcdef1234567abcdef'
                                }, ), 
                        type = 'executive', 
                        payload = { }, )
                    ],
        )

    def testVaultEventsResponse(self):
        """Test VaultEventsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.swap_response import SwapResponse  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestSwapResponse(unittest.TestCase):
    """SwapResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SwapResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.swap_response.SwapResponse()  # noqa: E501
        if include_optional :
            return SwapResponse(
                id = '0', 
                trade_type = 'ExactInput', 
                _in = 'USD', 
                out = 'USD', 
                amount = '0', 
                quote = '0', 
                rate = '0', 
                input_balance_after_swap = '0', 
                output_balance_after_swap = '0', 
                created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                expires_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                executed_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                value = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}
            )
        else :
            return SwapResponse(
                id = '0',
                trade_type = 'ExactInput',
                _in = 'USD',
                out = 'USD',
                amount = '0',
                quote = '0',
                rate = '0',
                created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                expires_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                value = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}},
        )

    def testSwapResponse(self):
        """Test SwapResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from zarban.wallet.openapi_client.api_client import ApiClient
from zarban.wallet.openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UserApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def confirm_kyc(self, kyc_confirm_request, **kwargs):  # noqa: E501
        """Confirm KYC  # noqa: E501

        Confirm KYC for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_kyc(kyc_confirm_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KycConfirmRequest kyc_confirm_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.confirm_kyc_with_http_info(kyc_confirm_request, **kwargs)  # noqa: E501

    def confirm_kyc_with_http_info(self, kyc_confirm_request, **kwargs):  # noqa: E501
        """Confirm KYC  # noqa: E501

        Confirm KYC for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_kyc_with_http_info(kyc_confirm_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KycConfirmRequest kyc_confirm_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'kyc_confirm_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method confirm_kyc" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'kyc_confirm_request' is set
        if self.api_client.client_side_validation and ('kyc_confirm_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['kyc_confirm_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `kyc_confirm_request` when calling `confirm_kyc`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'kyc_confirm_request' in local_var_params:
            body_params = local_var_params['kyc_confirm_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/kyc/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def confirm_phone_number(self, phone_otp_submit_request, **kwargs):  # noqa: E501
        """Confirm phone number  # noqa: E501

        Confirm the phone number of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_phone_number(phone_otp_submit_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PhoneOtpSubmitRequest phone_otp_submit_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.confirm_phone_number_with_http_info(phone_otp_submit_request, **kwargs)  # noqa: E501

    def confirm_phone_number_with_http_info(self, phone_otp_submit_request, **kwargs):  # noqa: E501
        """Confirm phone number  # noqa: E501

        Confirm the phone number of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_phone_number_with_http_info(phone_otp_submit_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PhoneOtpSubmitRequest phone_otp_submit_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone_otp_submit_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method confirm_phone_number" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'phone_otp_submit_request' is set
        if self.api_client.client_side_validation and ('phone_otp_submit_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone_otp_submit_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone_otp_submit_request` when calling `confirm_phone_number`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'phone_otp_submit_request' in local_var_params:
            body_params = local_var_params['phone_otp_submit_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/phone/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_child_user(self, create_child_user_request, **kwargs):  # noqa: E501
        """create a child user  # noqa: E501

        create a child user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_child_user(create_child_user_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateChildUserRequest create_child_user_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_child_user_with_http_info(create_child_user_request, **kwargs)  # noqa: E501

    def create_child_user_with_http_info(self, create_child_user_request, **kwargs):  # noqa: E501
        """create a child user  # noqa: E501

        create a child user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_child_user_with_http_info(create_child_user_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateChildUserRequest create_child_user_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(User, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_child_user_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_child_user" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_child_user_request' is set
        if self.api_client.client_side_validation and ('create_child_user_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_child_user_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_child_user_request` when calling `create_child_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_child_user_request' in local_var_params:
            body_params = local_var_params['create_child_user_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/children', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_profile(self, **kwargs):  # noqa: E501
        """Get profile  # noqa: E501

        Get the profile of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_profile(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ProfileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_user_profile_with_http_info(**kwargs)  # noqa: E501

    def get_user_profile_with_http_info(self, **kwargs):  # noqa: E501
        """Get profile  # noqa: E501

        Get the profile of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_profile_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ProfileResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_profile" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/profile', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submit_email_confirmation_otp(self, email_otp_submit_request, **kwargs):  # noqa: E501
        """Submit email confirmation OTP  # noqa: E501

        Submit email confirmation OTP for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_email_confirmation_otp(email_otp_submit_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param EmailOtpSubmitRequest email_otp_submit_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submit_email_confirmation_otp_with_http_info(email_otp_submit_request, **kwargs)  # noqa: E501

    def submit_email_confirmation_otp_with_http_info(self, email_otp_submit_request, **kwargs):  # noqa: E501
        """Submit email confirmation OTP  # noqa: E501

        Submit email confirmation OTP for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_email_confirmation_otp_with_http_info(email_otp_submit_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param EmailOtpSubmitRequest email_otp_submit_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_otp_submit_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_email_confirmation_otp" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_otp_submit_request' is set
        if self.api_client.client_side_validation and ('email_otp_submit_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_otp_submit_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_otp_submit_request` when calling `submit_email_confirmation_otp`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_otp_submit_request' in local_var_params:
            body_params = local_var_params['email_otp_submit_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/email/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submit_kyc(self, kyc_request, **kwargs):  # noqa: E501
        """Submit KYC  # noqa: E501

        Submit KYC for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_kyc(kyc_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KycRequest kyc_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: KycResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submit_kyc_with_http_info(kyc_request, **kwargs)  # noqa: E501

    def submit_kyc_with_http_info(self, kyc_request, **kwargs):  # noqa: E501
        """Submit KYC  # noqa: E501

        Submit KYC for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_kyc_with_http_info(kyc_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KycRequest kyc_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(KycResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'kyc_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_kyc" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'kyc_request' is set
        if self.api_client.client_side_validation and ('kyc_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['kyc_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `kyc_request` when calling `submit_kyc`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'kyc_request' in local_var_params:
            body_params = local_var_params['kyc_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/kyc', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='KycResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def verify_phone_number(self, update_phone_request, **kwargs):  # noqa: E501
        """Verify phone number  # noqa: E501

        Verify the phone number of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_phone_number(update_phone_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePhoneRequest update_phone_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.verify_phone_number_with_http_info(update_phone_request, **kwargs)  # noqa: E501

    def verify_phone_number_with_http_info(self, update_phone_request, **kwargs):  # noqa: E501
        """Verify phone number  # noqa: E501

        Verify the phone number of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_phone_number_with_http_info(update_phone_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePhoneRequest update_phone_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_phone_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method verify_phone_number" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_phone_request' is set
        if self.api_client.client_side_validation and ('update_phone_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_phone_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_phone_request` when calling `verify_phone_number`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_phone_request' in local_var_params:
            body_params = local_var_params['update_phone_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/phone', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def verify_user_email_address(self, update_email_request, **kwargs):  # noqa: E501
        """Verify email  # noqa: E501

        Verify the email of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_user_email_address(update_email_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateEmailRequest update_email_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.verify_user_email_address_with_http_info(update_email_request, **kwargs)  # noqa: E501

    def verify_user_email_address_with_http_info(self, update_email_request, **kwargs):  # noqa: E501
        """Verify email  # noqa: E501

        Verify the email of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_user_email_address_with_http_info(update_email_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateEmailRequest update_email_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_email_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method verify_user_email_address" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_email_request' is set
        if self.api_client.client_side_validation and ('update_email_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_email_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_email_request` when calling `verify_user_email_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_email_request' in local_var_params:
            body_params = local_var_params['update_email_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/users/email', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.coin import Coin  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestCoin(unittest.TestCase):
    """Coin unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Coin
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.coin.Coin()  # noqa: E501
        if include_optional :
            return Coin(
                config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                    is_tradeable = True, 
                    withdraw_fees = {"tron":"10"}, 
                    min_withdrawal = {"tron":"10"}, 
                    needs_memo = True, ), 
                symbol = 'USD', 
                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                logo_uri = '0', 
                depositable_networks = [
                    zarban.wallet.openapi_client.models.network.Network(
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', )
                    ], 
                withdrawable_networks = [
                    zarban.wallet.openapi_client.models.network.Network(
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', )
                    ], 
                content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                    title = '0', 
                    text = '0', 
                    bullets = [
                        '0'
                        ], )
            )
        else :
            return Coin(
                config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                    is_tradeable = True, 
                    withdraw_fees = {"tron":"10"}, 
                    min_withdrawal = {"tron":"10"}, 
                    needs_memo = True, ),
                symbol = 'USD',
                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"},
                logo_uri = '0',
                depositable_networks = [
                    zarban.wallet.openapi_client.models.network.Network(
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', )
                    ],
                withdrawable_networks = [
                    zarban.wallet.openapi_client.models.network.Network(
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', )
                    ],
                content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                    title = '0', 
                    text = '0', 
                    bullets = [
                        '0'
                        ], ),
        )

    def testCoin(self):
        """Test Coin"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class Ilk(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'symbol': 'Symbol',
        'minimum_collateralization_ratio': 'str',
        'maximum_loan_to_value': 'str',
        'liquidation_penalty': 'str',
        'debt_ceiling': 'dict(str, str)',
        'debt': 'dict(str, str)',
        'annual_stability_fee': 'str',
        'dust_limit': 'dict(str, str)',
        'price': 'dict(str, str)',
        'next_price': 'dict(str, str)',
        'join': 'str',
        'median': 'str',
        'gem': 'str',
        'clipper': 'str',
        'pip': 'str',
        'hole': 'dict(str, str)',
        'dirt': 'dict(str, str)',
        'available_to_borrow': 'dict(str, str)'
    }

    attribute_map = {
        'name': 'name',
        'symbol': 'symbol',
        'minimum_collateralization_ratio': 'minimumCollateralizationRatio',
        'maximum_loan_to_value': 'maximumLoanToValue',
        'liquidation_penalty': 'liquidationPenalty',
        'debt_ceiling': 'debtCeiling',
        'debt': 'debt',
        'annual_stability_fee': 'annualStabilityFee',
        'dust_limit': 'dustLimit',
        'price': 'price',
        'next_price': 'nextPrice',
        'join': 'join',
        'median': 'median',
        'gem': 'gem',
        'clipper': 'clipper',
        'pip': 'pip',
        'hole': 'hole',
        'dirt': 'dirt',
        'available_to_borrow': 'availableToBorrow'
    }

    def __init__(self, name=None, symbol=None, minimum_collateralization_ratio=None, maximum_loan_to_value=None, liquidation_penalty=None, debt_ceiling=None, debt=None, annual_stability_fee=None, dust_limit=None, price=None, next_price=None, join=None, median=None, gem=None, clipper=None, pip=None, hole=None, dirt=None, available_to_borrow=None, local_vars_configuration=None):  # noqa: E501
        """Ilk - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._symbol = None
        self._minimum_collateralization_ratio = None
        self._maximum_loan_to_value = None
        self._liquidation_penalty = None
        self._debt_ceiling = None
        self._debt = None
        self._annual_stability_fee = None
        self._dust_limit = None
        self._price = None
        self._next_price = None
        self._join = None
        self._median = None
        self._gem = None
        self._clipper = None
        self._pip = None
        self._hole = None
        self._dirt = None
        self._available_to_borrow = None
        self.discriminator = None

        self.name = name
        self.symbol = symbol
        self.minimum_collateralization_ratio = minimum_collateralization_ratio
        self.maximum_loan_to_value = maximum_loan_to_value
        self.liquidation_penalty = liquidation_penalty
        self.debt_ceiling = debt_ceiling
        self.debt = debt
        self.annual_stability_fee = annual_stability_fee
        self.dust_limit = dust_limit
        self.price = price
        self.next_price = next_price
        self.join = join
        self.median = median
        self.gem = gem
        self.clipper = clipper
        self.pip = pip
        self.hole = hole
        self.dirt = dirt
        self.available_to_borrow = available_to_borrow

    @property
    def name(self):
        """Gets the name of this Ilk.  # noqa: E501

        Name of the ILK  # noqa: E501

        :return: The name of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Ilk.

        Name of the ILK  # noqa: E501

        :param name: The name of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def symbol(self):
        """Gets the symbol of this Ilk.  # noqa: E501


        :return: The symbol of this Ilk.  # noqa: E501
        :rtype: Symbol
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this Ilk.


        :param symbol: The symbol of this Ilk.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and symbol is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol`, must not be `None`")  # noqa: E501

        self._symbol = symbol

    @property
    def minimum_collateralization_ratio(self):
        """Gets the minimum_collateralization_ratio of this Ilk.  # noqa: E501

        Minimum Collateralization Ratio  # noqa: E501

        :return: The minimum_collateralization_ratio of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._minimum_collateralization_ratio

    @minimum_collateralization_ratio.setter
    def minimum_collateralization_ratio(self, minimum_collateralization_ratio):
        """Sets the minimum_collateralization_ratio of this Ilk.

        Minimum Collateralization Ratio  # noqa: E501

        :param minimum_collateralization_ratio: The minimum_collateralization_ratio of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and minimum_collateralization_ratio is None:  # noqa: E501
            raise ValueError("Invalid value for `minimum_collateralization_ratio`, must not be `None`")  # noqa: E501

        self._minimum_collateralization_ratio = minimum_collateralization_ratio

    @property
    def maximum_loan_to_value(self):
        """Gets the maximum_loan_to_value of this Ilk.  # noqa: E501

        Maximum Loan To Value  # noqa: E501

        :return: The maximum_loan_to_value of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._maximum_loan_to_value

    @maximum_loan_to_value.setter
    def maximum_loan_to_value(self, maximum_loan_to_value):
        """Sets the maximum_loan_to_value of this Ilk.

        Maximum Loan To Value  # noqa: E501

        :param maximum_loan_to_value: The maximum_loan_to_value of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and maximum_loan_to_value is None:  # noqa: E501
            raise ValueError("Invalid value for `maximum_loan_to_value`, must not be `None`")  # noqa: E501

        self._maximum_loan_to_value = maximum_loan_to_value

    @property
    def liquidation_penalty(self):
        """Gets the liquidation_penalty of this Ilk.  # noqa: E501

        Liquidation Penalty  # noqa: E501

        :return: The liquidation_penalty of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._liquidation_penalty

    @liquidation_penalty.setter
    def liquidation_penalty(self, liquidation_penalty):
        """Sets the liquidation_penalty of this Ilk.

        Liquidation Penalty  # noqa: E501

        :param liquidation_penalty: The liquidation_penalty of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and liquidation_penalty is None:  # noqa: E501
            raise ValueError("Invalid value for `liquidation_penalty`, must not be `None`")  # noqa: E501

        self._liquidation_penalty = liquidation_penalty

    @property
    def debt_ceiling(self):
        """Gets the debt_ceiling of this Ilk.  # noqa: E501


        :return: The debt_ceiling of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._debt_ceiling

    @debt_ceiling.setter
    def debt_ceiling(self, debt_ceiling):
        """Sets the debt_ceiling of this Ilk.


        :param debt_ceiling: The debt_ceiling of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and debt_ceiling is None:  # noqa: E501
            raise ValueError("Invalid value for `debt_ceiling`, must not be `None`")  # noqa: E501

        self._debt_ceiling = debt_ceiling

    @property
    def debt(self):
        """Gets the debt of this Ilk.  # noqa: E501


        :return: The debt of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._debt

    @debt.setter
    def debt(self, debt):
        """Sets the debt of this Ilk.


        :param debt: The debt of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and debt is None:  # noqa: E501
            raise ValueError("Invalid value for `debt`, must not be `None`")  # noqa: E501

        self._debt = debt

    @property
    def annual_stability_fee(self):
        """Gets the annual_stability_fee of this Ilk.  # noqa: E501

        Annual Stability Fee  # noqa: E501

        :return: The annual_stability_fee of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._annual_stability_fee

    @annual_stability_fee.setter
    def annual_stability_fee(self, annual_stability_fee):
        """Sets the annual_stability_fee of this Ilk.

        Annual Stability Fee  # noqa: E501

        :param annual_stability_fee: The annual_stability_fee of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and annual_stability_fee is None:  # noqa: E501
            raise ValueError("Invalid value for `annual_stability_fee`, must not be `None`")  # noqa: E501

        self._annual_stability_fee = annual_stability_fee

    @property
    def dust_limit(self):
        """Gets the dust_limit of this Ilk.  # noqa: E501


        :return: The dust_limit of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._dust_limit

    @dust_limit.setter
    def dust_limit(self, dust_limit):
        """Sets the dust_limit of this Ilk.


        :param dust_limit: The dust_limit of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and dust_limit is None:  # noqa: E501
            raise ValueError("Invalid value for `dust_limit`, must not be `None`")  # noqa: E501

        self._dust_limit = dust_limit

    @property
    def price(self):
        """Gets the price of this Ilk.  # noqa: E501


        :return: The price of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this Ilk.


        :param price: The price of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def next_price(self):
        """Gets the next_price of this Ilk.  # noqa: E501


        :return: The next_price of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._next_price

    @next_price.setter
    def next_price(self, next_price):
        """Sets the next_price of this Ilk.


        :param next_price: The next_price of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and next_price is None:  # noqa: E501
            raise ValueError("Invalid value for `next_price`, must not be `None`")  # noqa: E501

        self._next_price = next_price

    @property
    def join(self):
        """Gets the join of this Ilk.  # noqa: E501

        Join Address  # noqa: E501

        :return: The join of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._join

    @join.setter
    def join(self, join):
        """Sets the join of this Ilk.

        Join Address  # noqa: E501

        :param join: The join of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and join is None:  # noqa: E501
            raise ValueError("Invalid value for `join`, must not be `None`")  # noqa: E501

        self._join = join

    @property
    def median(self):
        """Gets the median of this Ilk.  # noqa: E501

        Median Address  # noqa: E501

        :return: The median of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._median

    @median.setter
    def median(self, median):
        """Sets the median of this Ilk.

        Median Address  # noqa: E501

        :param median: The median of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and median is None:  # noqa: E501
            raise ValueError("Invalid value for `median`, must not be `None`")  # noqa: E501

        self._median = median

    @property
    def gem(self):
        """Gets the gem of this Ilk.  # noqa: E501

        Gem Address  # noqa: E501

        :return: The gem of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._gem

    @gem.setter
    def gem(self, gem):
        """Sets the gem of this Ilk.

        Gem Address  # noqa: E501

        :param gem: The gem of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and gem is None:  # noqa: E501
            raise ValueError("Invalid value for `gem`, must not be `None`")  # noqa: E501

        self._gem = gem

    @property
    def clipper(self):
        """Gets the clipper of this Ilk.  # noqa: E501

        Clipper Address  # noqa: E501

        :return: The clipper of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._clipper

    @clipper.setter
    def clipper(self, clipper):
        """Sets the clipper of this Ilk.

        Clipper Address  # noqa: E501

        :param clipper: The clipper of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and clipper is None:  # noqa: E501
            raise ValueError("Invalid value for `clipper`, must not be `None`")  # noqa: E501

        self._clipper = clipper

    @property
    def pip(self):
        """Gets the pip of this Ilk.  # noqa: E501

        Pip Address  # noqa: E501

        :return: The pip of this Ilk.  # noqa: E501
        :rtype: str
        """
        return self._pip

    @pip.setter
    def pip(self, pip):
        """Sets the pip of this Ilk.

        Pip Address  # noqa: E501

        :param pip: The pip of this Ilk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pip is None:  # noqa: E501
            raise ValueError("Invalid value for `pip`, must not be `None`")  # noqa: E501

        self._pip = pip

    @property
    def hole(self):
        """Gets the hole of this Ilk.  # noqa: E501


        :return: The hole of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._hole

    @hole.setter
    def hole(self, hole):
        """Sets the hole of this Ilk.


        :param hole: The hole of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and hole is None:  # noqa: E501
            raise ValueError("Invalid value for `hole`, must not be `None`")  # noqa: E501

        self._hole = hole

    @property
    def dirt(self):
        """Gets the dirt of this Ilk.  # noqa: E501


        :return: The dirt of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._dirt

    @dirt.setter
    def dirt(self, dirt):
        """Sets the dirt of this Ilk.


        :param dirt: The dirt of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and dirt is None:  # noqa: E501
            raise ValueError("Invalid value for `dirt`, must not be `None`")  # noqa: E501

        self._dirt = dirt

    @property
    def available_to_borrow(self):
        """Gets the available_to_borrow of this Ilk.  # noqa: E501


        :return: The available_to_borrow of this Ilk.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._available_to_borrow

    @available_to_borrow.setter
    def available_to_borrow(self, available_to_borrow):
        """Sets the available_to_borrow of this Ilk.


        :param available_to_borrow: The available_to_borrow of this Ilk.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and available_to_borrow is None:  # noqa: E501
            raise ValueError("Invalid value for `available_to_borrow`, must not be `None`")  # noqa: E501

        self._available_to_borrow = available_to_borrow

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Ilk):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Ilk):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.api.swap_api import SwapApi  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException


class TestSwapApi(unittest.TestCase):
    """SwapApi unit test stubs"""

    def setUp(self):
        self.api = zarban.wallet.openapi_client.api.swap_api.SwapApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_swap_coins(self):
        """Test case for swap_coins

        Swap coins  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class Referral(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'referrer_id': 'int',
        'name': 'str',
        'usage_limit': 'int',
        'usage_count': 'int',
        'created_at': 'Timestamp',
        'link': 'str',
        'share_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'referrer_id': 'referrerId',
        'name': 'name',
        'usage_limit': 'usageLimit',
        'usage_count': 'usageCount',
        'created_at': 'createdAt',
        'link': 'link',
        'share_url': 'shareUrl'
    }

    def __init__(self, id=None, referrer_id=None, name=None, usage_limit=None, usage_count=None, created_at=None, link=None, share_url=None, local_vars_configuration=None):  # noqa: E501
        """Referral - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._referrer_id = None
        self._name = None
        self._usage_limit = None
        self._usage_count = None
        self._created_at = None
        self._link = None
        self._share_url = None
        self.discriminator = None

        self.id = id
        self.referrer_id = referrer_id
        self.name = name
        self.usage_limit = usage_limit
        self.usage_count = usage_count
        self.created_at = created_at
        self.link = link
        if share_url is not None:
            self.share_url = share_url

    @property
    def id(self):
        """Gets the id of this Referral.  # noqa: E501


        :return: The id of this Referral.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Referral.


        :param id: The id of this Referral.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def referrer_id(self):
        """Gets the referrer_id of this Referral.  # noqa: E501


        :return: The referrer_id of this Referral.  # noqa: E501
        :rtype: int
        """
        return self._referrer_id

    @referrer_id.setter
    def referrer_id(self, referrer_id):
        """Sets the referrer_id of this Referral.


        :param referrer_id: The referrer_id of this Referral.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and referrer_id is None:  # noqa: E501
            raise ValueError("Invalid value for `referrer_id`, must not be `None`")  # noqa: E501

        self._referrer_id = referrer_id

    @property
    def name(self):
        """Gets the name of this Referral.  # noqa: E501


        :return: The name of this Referral.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Referral.


        :param name: The name of this Referral.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def usage_limit(self):
        """Gets the usage_limit of this Referral.  # noqa: E501


        :return: The usage_limit of this Referral.  # noqa: E501
        :rtype: int
        """
        return self._usage_limit

    @usage_limit.setter
    def usage_limit(self, usage_limit):
        """Sets the usage_limit of this Referral.


        :param usage_limit: The usage_limit of this Referral.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and usage_limit is None:  # noqa: E501
            raise ValueError("Invalid value for `usage_limit`, must not be `None`")  # noqa: E501

        self._usage_limit = usage_limit

    @property
    def usage_count(self):
        """Gets the usage_count of this Referral.  # noqa: E501


        :return: The usage_count of this Referral.  # noqa: E501
        :rtype: int
        """
        return self._usage_count

    @usage_count.setter
    def usage_count(self, usage_count):
        """Sets the usage_count of this Referral.


        :param usage_count: The usage_count of this Referral.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and usage_count is None:  # noqa: E501
            raise ValueError("Invalid value for `usage_count`, must not be `None`")  # noqa: E501

        self._usage_count = usage_count

    @property
    def created_at(self):
        """Gets the created_at of this Referral.  # noqa: E501


        :return: The created_at of this Referral.  # noqa: E501
        :rtype: Timestamp
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Referral.


        :param created_at: The created_at of this Referral.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def link(self):
        """Gets the link of this Referral.  # noqa: E501


        :return: The link of this Referral.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Referral.


        :param link: The link of this Referral.  # noqa: E501
        :type: str
        """

        self._link = link

    @property
    def share_url(self):
        """Gets the share_url of this Referral.  # noqa: E501


        :return: The share_url of this Referral.  # noqa: E501
        :rtype: str
        """
        return self._share_url

    @share_url.setter
    def share_url(self, share_url):
        """Sets the share_url of this Referral.


        :param share_url: The share_url of this Referral.  # noqa: E501
        :type: str
        """

        self._share_url = share_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Referral):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Referral):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from zarban.wallet.openapi_client.api.auth_api import AuthApi
from zarban.wallet.openapi_client.api.balance_api import BalanceApi
from zarban.wallet.openapi_client.api.coins_api import CoinsApi
from zarban.wallet.openapi_client.api.deposit_api import DepositApi
from zarban.wallet.openapi_client.api.health_api import HealthApi
from zarban.wallet.openapi_client.api.loans_api import LoansApi
from zarban.wallet.openapi_client.api.payment_api import PaymentApi
from zarban.wallet.openapi_client.api.points_api import PointsApi
from zarban.wallet.openapi_client.api.redemptions_api import RedemptionsApi
from zarban.wallet.openapi_client.api.referrals_api import ReferralsApi
from zarban.wallet.openapi_client.api.swap_api import SwapApi
from zarban.wallet.openapi_client.api.tasks_api import TasksApi
from zarban.wallet.openapi_client.api.transactions_api import TransactionsApi
from zarban.wallet.openapi_client.api.user_api import UserApi
from zarban.wallet.openapi_client.api.withdraw_api import WithdrawApi



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class Token(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'symbol': 'Symbol',
        'decimals': 'int',
        'address': 'str',
        'logo_uri': 'str',
        'chain_id': 'int',
        'persian_name': 'str'
    }

    attribute_map = {
        'name': 'name',
        'symbol': 'symbol',
        'decimals': 'decimals',
        'address': 'address',
        'logo_uri': 'logoUri',
        'chain_id': 'chainId',
        'persian_name': 'persianName'
    }

    def __init__(self, name=None, symbol=None, decimals=None, address=None, logo_uri=None, chain_id=None, persian_name=None, local_vars_configuration=None):  # noqa: E501
        """Token - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._symbol = None
        self._decimals = None
        self._address = None
        self._logo_uri = None
        self._chain_id = None
        self._persian_name = None
        self.discriminator = None

        self.name = name
        self.symbol = symbol
        self.decimals = decimals
        self.address = address
        self.logo_uri = logo_uri
        self.chain_id = chain_id
        self.persian_name = persian_name

    @property
    def name(self):
        """Gets the name of this Token.  # noqa: E501

        The name of the token.  # noqa: E501

        :return: The name of this Token.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Token.

        The name of the token.  # noqa: E501

        :param name: The name of this Token.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def symbol(self):
        """Gets the symbol of this Token.  # noqa: E501


        :return: The symbol of this Token.  # noqa: E501
        :rtype: Symbol
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this Token.


        :param symbol: The symbol of this Token.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and symbol is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol`, must not be `None`")  # noqa: E501

        self._symbol = symbol

    @property
    def decimals(self):
        """Gets the decimals of this Token.  # noqa: E501

        The number of decimals for the token.  # noqa: E501

        :return: The decimals of this Token.  # noqa: E501
        :rtype: int
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this Token.

        The number of decimals for the token.  # noqa: E501

        :param decimals: The decimals of this Token.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and decimals is None:  # noqa: E501
            raise ValueError("Invalid value for `decimals`, must not be `None`")  # noqa: E501

        self._decimals = decimals

    @property
    def address(self):
        """Gets the address of this Token.  # noqa: E501

        The Ethereum address of the token.  # noqa: E501

        :return: The address of this Token.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Token.

        The Ethereum address of the token.  # noqa: E501

        :param address: The address of this Token.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address is None:  # noqa: E501
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def logo_uri(self):
        """Gets the logo_uri of this Token.  # noqa: E501

        The URI of the token's logo.  # noqa: E501

        :return: The logo_uri of this Token.  # noqa: E501
        :rtype: str
        """
        return self._logo_uri

    @logo_uri.setter
    def logo_uri(self, logo_uri):
        """Sets the logo_uri of this Token.

        The URI of the token's logo.  # noqa: E501

        :param logo_uri: The logo_uri of this Token.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and logo_uri is None:  # noqa: E501
            raise ValueError("Invalid value for `logo_uri`, must not be `None`")  # noqa: E501

        self._logo_uri = logo_uri

    @property
    def chain_id(self):
        """Gets the chain_id of this Token.  # noqa: E501

        The chain ID of the token.  # noqa: E501

        :return: The chain_id of this Token.  # noqa: E501
        :rtype: int
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this Token.

        The chain ID of the token.  # noqa: E501

        :param chain_id: The chain_id of this Token.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and chain_id is None:  # noqa: E501
            raise ValueError("Invalid value for `chain_id`, must not be `None`")  # noqa: E501

        self._chain_id = chain_id

    @property
    def persian_name(self):
        """Gets the persian_name of this Token.  # noqa: E501

        The Persian name of the token.  # noqa: E501

        :return: The persian_name of this Token.  # noqa: E501
        :rtype: str
        """
        return self._persian_name

    @persian_name.setter
    def persian_name(self, persian_name):
        """Sets the persian_name of this Token.

        The Persian name of the token.  # noqa: E501

        :param persian_name: The persian_name of this Token.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and persian_name is None:  # noqa: E501
            raise ValueError("Invalid value for `persian_name`, must not be `None`")  # noqa: E501

        self._persian_name = persian_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Token):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Token):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from zarban.wallet.openapi_client.api_client import ApiClient
from zarban.wallet.openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AuthApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def authenticate_with_telegram(self, auth_telegram_request, **kwargs):  # noqa: E501
        """Authenticate with Telegram  # noqa: E501

        Authenticate with Telegram and get a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authenticate_with_telegram(auth_telegram_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AuthTelegramRequest auth_telegram_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JwtResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.authenticate_with_telegram_with_http_info(auth_telegram_request, **kwargs)  # noqa: E501

    def authenticate_with_telegram_with_http_info(self, auth_telegram_request, **kwargs):  # noqa: E501
        """Authenticate with Telegram  # noqa: E501

        Authenticate with Telegram and get a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authenticate_with_telegram_with_http_info(auth_telegram_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AuthTelegramRequest auth_telegram_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JwtResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'auth_telegram_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method authenticate_with_telegram" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'auth_telegram_request' is set
        if self.api_client.client_side_validation and ('auth_telegram_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['auth_telegram_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `auth_telegram_request` when calling `authenticate_with_telegram`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'auth_telegram_request' in local_var_params:
            body_params = local_var_params['auth_telegram_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/telegram', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JwtResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_jwt_token(self, duration, **kwargs):  # noqa: E501
        """Generate a JWT token  # noqa: E501

        Generate a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_jwt_token(duration, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int duration: Token duration in days (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JwtResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.generate_jwt_token_with_http_info(duration, **kwargs)  # noqa: E501

    def generate_jwt_token_with_http_info(self, duration, **kwargs):  # noqa: E501
        """Generate a JWT token  # noqa: E501

        Generate a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_jwt_token_with_http_info(duration, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int duration: Token duration in days (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JwtResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'duration'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_jwt_token" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'duration' is set
        if self.api_client.client_side_validation and ('duration' not in local_var_params or  # noqa: E501
                                                        local_var_params['duration'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `duration` when calling `generate_jwt_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'duration' in local_var_params and local_var_params['duration'] is not None:  # noqa: E501
            query_params.append(('duration', local_var_params['duration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/auth/token', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JwtResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_otp(self, channel, **kwargs):  # noqa: E501
        """Get OTP  # noqa: E501

        Get OTP for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_otp(channel, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str channel: Channel to send OTP (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_otp_with_http_info(channel, **kwargs)  # noqa: E501

    def get_otp_with_http_info(self, channel, **kwargs):  # noqa: E501
        """Get OTP  # noqa: E501

        Get OTP for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_otp_with_http_info(channel, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str channel: Channel to send OTP (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'channel'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_otp" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'channel' is set
        if self.api_client.client_side_validation and ('channel' not in local_var_params or  # noqa: E501
                                                        local_var_params['channel'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `channel` when calling `get_otp`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'channel' in local_var_params and local_var_params['channel'] is not None:  # noqa: E501
            query_params.append(('channel', local_var_params['channel']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/auth/otp', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def login_with_email_and_password(self, login_request, **kwargs):  # noqa: E501
        """Login with email and password  # noqa: E501

        Login with email and password and get a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.login_with_email_and_password(login_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LoginRequest login_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JwtResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.login_with_email_and_password_with_http_info(login_request, **kwargs)  # noqa: E501

    def login_with_email_and_password_with_http_info(self, login_request, **kwargs):  # noqa: E501
        """Login with email and password  # noqa: E501

        Login with email and password and get a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.login_with_email_and_password_with_http_info(login_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LoginRequest login_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JwtResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'login_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method login_with_email_and_password" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'login_request' is set
        if self.api_client.client_side_validation and ('login_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['login_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `login_request` when calling `login_with_email_and_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'login_request' in local_var_params:
            body_params = local_var_params['login_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/login', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JwtResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def signup_with_email_and_password(self, sign_up_request, **kwargs):  # noqa: E501
        """signup with email and password  # noqa: E501

        signup with email and password and get a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.signup_with_email_and_password(sign_up_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SignUpRequest sign_up_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.signup_with_email_and_password_with_http_info(sign_up_request, **kwargs)  # noqa: E501

    def signup_with_email_and_password_with_http_info(self, sign_up_request, **kwargs):  # noqa: E501
        """signup with email and password  # noqa: E501

        signup with email and password and get a JWT token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.signup_with_email_and_password_with_http_info(sign_up_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SignUpRequest sign_up_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sign_up_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method signup_with_email_and_password" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sign_up_request' is set
        if self.api_client.client_side_validation and ('sign_up_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['sign_up_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sign_up_request` when calling `signup_with_email_and_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sign_up_request' in local_var_params:
            body_params = local_var_params['sign_up_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/signup', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def verify_user_email(self, token, **kwargs):  # noqa: E501
        """Verify email  # noqa: E501

        Verify the email of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_user_email(token, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str token: Verification token (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JwtResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.verify_user_email_with_http_info(token, **kwargs)  # noqa: E501

    def verify_user_email_with_http_info(self, token, **kwargs):  # noqa: E501
        """Verify email  # noqa: E501

        Verify the email of the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_user_email_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str token: Verification token (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JwtResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'token'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method verify_user_email" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'token' is set
        if self.api_client.client_side_validation and ('token' not in local_var_params or  # noqa: E501
                                                        local_var_params['token'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `token` when calling `verify_user_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'token' in local_var_params and local_var_params['token'] is not None:  # noqa: E501
            query_params.append(('token', local_var_params['token']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/verify-email', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JwtResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
